@@ -1,6 +1,6 @@
 from dataclasses import dataclass, field
-from typing import List,Optional
-from sdk.models import shared
+from typing import Optional
+from .. import shared
 
 
 @dataclass
@@ -18,6 +18,6 @@ class GetAllForVersionAPIEndpointsRequest:
 class GetAllForVersionAPIEndpointsResponse:
     content_type: str = field()
     status_code: int = field()
-    api_endpoints: Optional[List[shared.APIEndpoint]] = field(default=None)
+    api_endpoints: Optional[list[shared.APIEndpoint]] = field(default=None)
     error: Optional[shared.Error] = field(default=None)
     
